@@ -25,6 +25,7 @@ ORE_EVE_GROUPS = [
     1923,
     2024,
     2029,
+    4029,
     4030,
     4031,
     4094,
@@ -32,6 +33,8 @@ ORE_EVE_GROUPS = [
 
 OPE_EVE_GROUPS = [493]
 
+BONDS_EVE_GROUPS = [1248]
+
 BLUE_LOOT_TYPE_IDS = [
     30744,
     30745,
